@@ -83,22 +83,11 @@ class TgUpload:
             # make sure producers done
             for p in self.producers:
                 p.join()
-    
-    def clean_up(self):
-        dir_path = self.directory
-        res = glob.glob(dir_path)
-
-        for file_path in res:
-            try:
-                os.remove(file_path)
-            except:
-                logging.error("Error while deleting file : ", file_path)
 
     def run(self):
         self.start_workers()
         self.start_producers()
         self.q.join()
-        #self.clean_up()
         logging.info('All work completed')
 
 
